PROGRAM_NAME='AudioReQuest Demo v5_0_1.axs'
(************************************************************)
(* System Type : NetLinx									*)
(************************************************************)
(* REV HISTORY:												*)
(*  2.5.1   -Initial Version								*)
(*  3.0.1   -Added new commands and feedback available in	*)
(*           ARQ firmware 1.9.3								*)
(*  3.0.2   -Fixed NVRam overflow issue with adding more	*)
(*			 than 7 Panels or AudioReQuests					*)
(*			-Added error checking to ignore any channel		*)
(*			 event assigned to channel 9999 (unused)		*)
(*  5.0.0   -Modified existing program to work with the		*)
(*			 F-Series										*)
(*			-Added WEB_PORT to ARQ_COMM_DATA structure		*)
(*			-Added DISCONNECT array to turn off feedback	*)
(*	5.0.1	-Fixed problem with using a WEB_PORT other than	*)
(*			 80												*)
(************************************************************)
(* **NOTE:  The source code for the Module files are NOT	*)
(*          included in this demo.  You should not need it	*)
(*          for any reason, but you will get an error if	*)
(*          you attempt to build the whole system.			*)
(************************************************************)
(* Important Setup Information:								*)
(*   1) Add/Remove ARQ, touch panel and DMS devices as		*)
(*      necessary											*)
(*   2) For each ARQ in the system, you need 1 instance of	*)
(*		the 'ARQ Comm v5_0_1' module (see below)			*)
(*		**Be sure to set the zone number correctly!!!		*)
(*   3) For each touch panel that will control the			*)
(*      AudioReQuest, you need 1 instance of the			*)
(*      'ARQ TP UI v5_0_1' module (see below)				*)
(*   4) For each DMS keypad that will control the			*)
(*      AudioReQuest, you need 1 instance of the			*)
(*      'ARQ DMS UI v5_0_1' module (see below)				*)
(*   5) Open the 'ARQ Main v5_0_1.axi' file and modify the	*)
(*      IP Address, Baud Rate, Port number, or Zone number	*)
(*      as necessary.  You can find and set the IP Address	*)
(*		on the ARQ by going to Menu-->Settings-->Network	*)
(*		Configuration.										*)
(*      **NOTE:  If you change the IP address on the ARQ,	*)
(*               you MUST reboot the ARQ for the settings	*)
(*               to take effect.							*)
(*   6) Open the 'ARQ TP Interface v5_0_1.axi' include		*)
(*      file and modify any of the Command Channel arrays	*)
(*      as necessary.  See comments in that file for more	*)
(*      information.										*)
(************************************************************)

(************************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW				*)
(************************************************************)
DEFINE_DEVICE
dvARQ1 = 0:2:0;				//Set the IP Address or Baud settings in the ARQ Main v5_0_1 file!!
dvARQ2 = 0:3:0;				//Set the IP Address or Baud settings in the ARQ Main v5_0_1 file!!
dvARQ3 = 0:4:0;				//Set the IP Address or Baud settings in the ARQ Main v5_0_1 file!!

arqTP1 = 10001:1:0;			//Touch panel device 1
arqTP2 = 10002:1:0;			//Touch panel device 2
arqTP3 = 10003:1:0;			//Touch panel device 3
arqTP4 = 10004:1:0;			//Touch panel device 3

arqDMS1 = 6001:1:0;			//DMS 1 for ReQuest
arqDMS2 = 6002:1:0;			//DMS 2 for ReQuest
arqDMS3 = 6003:1:0;			//DMS 3 for ReQuest
arqDMS4 = 6004:1:0;			//DMS 4 for ReQuest

vdvARQ1_1 = 34000:1:0;		//Virtual device for ARQ 1, Zone 1
vdvARQ1_2 = 34001:1:0;		//Virtual device for ARQ 1, Zone 2
vdvARQ1_3 = 34002:1:0;		//Virtual device for ARQ 1, Zone 3
vdvARQ1_4 = 34003:1:0;		//Virtual device for ARQ 1, Zone 4
vdvARQ2_0 = 34004:1:0;		//Virtual device for ARQ 2, Zone 0
vdvARQ3_0 = 34005:1:0;		//Virtual device for ARQ 3, Zone 0

vdvDMS1 = 34011:1:0;		//Virtual device for DMS 1
vdvDMS2 = 34012:1:0;		//Virtual device for DMS 2
vdvDMS3 = 34013:1:0;		//Virtual device for DMS 3
vdvDMS4 = 34014:1:0;		//Virtual device for DMS 4

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

#include 'ARQ Defines v5_0_1.axi';
#include 'ARQ Main v5_0_1.axi';
#include 'ARQ TP Interface v5_0_1.axi';
#include 'ARQ DMS Interface v5_0_1.axi';
(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START


DEFINE_MODULE 'DMS-IMSMod' DMS_MOD_1 (vdvDMS1, arqDMS1, ARQ_DMS_FILENAME, ARQ_DMS_TEXT_1);
DEFINE_MODULE 'DMS-IMSMod' DMS_MOD_2 (vdvDMS2, arqDMS2, ARQ_DMS_FILENAME, ARQ_DMS_TEXT_2);
DEFINE_MODULE 'DMS-IMSMod' DMS_MOD_3 (vdvDMS3, arqDMS3, ARQ_DMS_FILENAME, ARQ_DMS_TEXT_3);
DEFINE_MODULE 'DMS-IMSMod' DMS_MOD_4 (vdvDMS4, arqDMS4, ARQ_DMS_FILENAME, ARQ_DMS_TEXT_4);

/************************************************************
 You need 1 instance of the ARQ Comm v1_1 module for each
 AudioReQuest device.
*************************************************************/
#if_defined vdvARQ1_1
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_1_1   (dvARQ1,					//Actual AudioReQuest Device
												vdvARQ1_1,				//Virtual AudioReQuest Device
												ARQ_COMM_1.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_1.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_1.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_1.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_1);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if
#if_defined vdvARQ1_2
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_1_2   (dvARQ1,					//Actual AudioReQuest Device
												vdvARQ1_2,				//Virtual AudioReQuest Device
												ARQ_COMM_1.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_1.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_1.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_1.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_2);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if
#if_defined vdvARQ1_3
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_1_3   (dvARQ1,					//Actual AudioReQuest Device
												vdvARQ1_3,				//Virtual AudioReQuest Device
												ARQ_COMM_1.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_1.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_1.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_1.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_3);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if
#if_defined vdvARQ1_4
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_1_4   (dvARQ1,					//Actual AudioReQuest Device
												vdvARQ1_4,				//Virtual AudioReQuest Device
												ARQ_COMM_1.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_1.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_1.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_1.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_4);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if

#if_defined vdvARQ2_0
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_2_0   (dvARQ2,					//Actual AudioReQuest Device
												vdvARQ2_0,				//Virtual AudioReQuest Device
												ARQ_COMM_2.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_2.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_2.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_2.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_0);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if

#if_defined vdvARQ3_0
DEFINE_MODULE 'ARQ Comm v5_0_1' ARQ_Comm_3_0   (dvARQ3,					//Actual AudioReQuest Device
												vdvARQ3_0,				//Virtual AudioReQuest Device
												ARQ_COMM_3.IP_ADDRESS,	//AudioReQuest IP Address
												ARQ_COMM_3.CTRL_PORT,	//AudioReQuest Control Port
												ARQ_COMM_3.WEB_PORT,	//AudioReQuest Web Port
												ARQ_COMM_3.BAUD_RATE,	//AudioReQuest Baud Rate
												ZONE_0);				//AudioReQuest Zone Number (1-4, 0 for old singlezone units)
#end_if


/************************************************************
 You need 1 instance of the ARQ TP UI v5_0_1 module for EACH
 touch screen that will control the AudioReQuest.  This demo
 is designed with 4.  Add/Remove these modules as necessary.
 **Be sure to change the name of the module (ARQ_TP_1, 2, 3, ...)
   and the arqTP# device name as necessary.  All other
   parameters should remain the same in each module.
*************************************************************/
#if_defined arqTP1
DEFINE_MODULE 'ARQ TP UI v5_0_1' ARQ_TP_1    (arqTP1,					//Touch Panel Device
                                              ARQ_UNITS,				//Virtual AudioReQuest Devices
                                              ARQ_SELECT,				//ARQ selection channels
                                              ARQ_DISCONNECT,			//ARQ deselection channel
                                              ARQ_CMDS,					//Command Channel Array
                                              ARQ_ADV_CMDS,				//Advanced Command Channel Array
                                              ARQ_KEYBOARD_CH,			//Keyboard Channel Array
                                              ARQ_NUM_CH,				//Numbers Channel Array
                                              ARQ_FB_CH,				//Variable Text Channel Array
                                              ARQ_ELAPSED_LVL,			//Level for Elapsed Time progress bar
                                              ARQ_DYNAMIC_IMAGES,		//Dynamic image resource names for Cover Art
                                              ARQ_LINE_PRESS_DOUBLE,	//Line Press Type (single or double)
                                              ARQ_NUM_LINES[6]);		//Number of lines on Browse page (change array index to 1-8)
#end_if

#if_defined arqTP2
DEFINE_MODULE 'ARQ TP UI v5_0_1' ARQ_TP_2    (arqTP2,					//Touch Panel Device
                                              ARQ_UNITS,				//Virtual AudioReQuest Devices
                                              ARQ_SELECT,				//ARQ selection channels
                                              ARQ_DISCONNECT,			//ARQ deselection channel
                                              ARQ_CMDS,					//Command Channel Array
                                              ARQ_ADV_CMDS,				//Advanced Command Channel Array
                                              ARQ_KEYBOARD_CH,			//Keyboard Channel Array
                                              ARQ_NUM_CH,				//Numbers Channel Array
                                              ARQ_FB_CH,				//Variable Text Channel Array
                                              ARQ_ELAPSED_LVL,			//Level for Elapsed Time progress bar
                                              ARQ_DYNAMIC_IMAGES,		//Dynamic image resource names for Cover Art
                                              ARQ_LINE_PRESS_DOUBLE,	//Line Press Type (single or double)
                                              ARQ_NUM_LINES[6]);		//Number of lines on Browse page (change array index to 1-8)
#end_if

#if_defined arqTP3
DEFINE_MODULE 'ARQ TP UI v5_0_1' ARQ_TP_3    (arqTP3,					//Touch Panel Device
                                              ARQ_UNITS,				//Virtual AudioReQuest Devices
                                              ARQ_SELECT,				//ARQ selection channels
                                              ARQ_DISCONNECT,			//ARQ deselection channel
                                              ARQ_CMDS,					//Command Channel Array
                                              ARQ_ADV_CMDS,				//Advanced Command Channel Array
                                              ARQ_KEYBOARD_CH,			//Keyboard Channel Array
                                              ARQ_NUM_CH,				//Numbers Channel Array
                                              ARQ_FB_CH,				//Variable Text Channel Array
                                              ARQ_ELAPSED_LVL,			//Level for Elapsed Time progress bar
                                              ARQ_DYNAMIC_IMAGES,		//Dynamic image resource names for Cover Art
                                              ARQ_LINE_PRESS_DOUBLE,	//Line Press Type (single or double)
                                              ARQ_NUM_LINES[6]);		//Number of lines on Browse page (change array index to 1-8)
#end_if
#if_defined arqTP4
DEFINE_MODULE 'ARQ TP UI v5_0_1' ARQ_TP_4    (arqTP4,					//Touch Panel Device
                                              ARQ_UNITS,				//Virtual AudioReQuest Devices
                                              ARQ_SELECT,				//ARQ selection channels
                                              ARQ_DISCONNECT,			//ARQ deselection channel
                                              ARQ_CMDS,					//Command Channel Array
                                              ARQ_ADV_CMDS,				//Advanced Command Channel Array
                                              ARQ_KEYBOARD_CH,			//Keyboard Channel Array
                                              ARQ_NUM_CH,				//Numbers Channel Array
                                              ARQ_FB_CH,				//Variable Text Channel Array
                                              ARQ_ELAPSED_LVL,			//Level for Elapsed Time progress bar
                                              ARQ_DYNAMIC_IMAGES,		//Dynamic image resource names for Cover Art
                                              ARQ_LINE_PRESS_DOUBLE,	//Line Press Type (single or double)
                                              ARQ_NUM_LINES[6]);		//Number of lines on Browse page (change array index to 1-8)
#end_if


/************************************************************
 You need 1 instance of the ARQ DMS UI v5_0_1 module for EACH
 DMS Keypad that will control the AudioReQuest.  This demo
 is designed with 4.  Add/Remove these modules as necessary.
 **Be sure to change the name of the module (ARQ_DMS_1, 2, 3, ...)
   and the vdvDMS# device name as necessary.  All other
   parameters should remain the same in each module.
*************************************************************/
#if_defined arqDMS1
DEFINE_MODULE 'ARQ DMS UI v5_0_1' ARQ_DMS_1    (vdvDMS1,				//Virtual Keypad Device
                                                ARQ_UNITS,				//Virtual AudioReQuest Devices
                                                ARQ_SELECT_DMS,			//ARQ selection channels
												ARQ_DISCONNECT_DMS,		//ARQ deselection channel
                                                ARQ_CMDS_DMS,			//Command Channel Array
                                                ARQ_KEYBOARD_CH_DMS,	//Keyboard Channel Array
                                                ARQ_NUM_CH_DMS,			//Numbers Channel Array
                                                ARQ_FB_CH_DMS,			//Variable Text Channel Array
                                                ARQ_NUM_LINES[4], 		//Number of lines on Browse page (change array index to 1-8)
												REFRESH_RATE);			//Number of milliseconds before text refreshes
#end_if

#if_defined arqDMS2
DEFINE_MODULE 'ARQ DMS UI v5_0_1' ARQ_DMS_2    (vdvDMS2,				//Virtual Keypad Device
                                                ARQ_UNITS,				//Virtual AudioReQuest Devices
                                                ARQ_SELECT_DMS,			//ARQ selection channels
												ARQ_DISCONNECT_DMS,		//ARQ deselection channel
                                                ARQ_CMDS_DMS,			//Command Channel Array
                                                ARQ_KEYBOARD_CH_DMS,	//Keyboard Channel Array
                                                ARQ_NUM_CH_DMS,			//Numbers Channel Array
                                                ARQ_FB_CH_DMS,			//Variable Text Channel Array
                                                ARQ_NUM_LINES[4], 		//Number of lines on Browse page (change array index to 1-8)
												REFRESH_RATE);			//Number of milliseconds before text refreshes
#end_if

#if_defined arqDMS3
DEFINE_MODULE 'ARQ DMS UI v5_0_1' ARQ_DMS_3    (vdvDMS3,				//Virtual Keypad Device
                                                ARQ_UNITS,				//Virtual AudioReQuest Devices
                                                ARQ_SELECT_DMS,			//ARQ selection channels
												ARQ_DISCONNECT_DMS,		//ARQ deselection channel
                                                ARQ_CMDS_DMS,			//Command Channel Array
                                                ARQ_KEYBOARD_CH_DMS,	//Keyboard Channel Array
                                                ARQ_NUM_CH_DMS,			//Numbers Channel Array
                                                ARQ_FB_CH_DMS,			//Variable Text Channel Array
                                                ARQ_NUM_LINES[4], 		//Number of lines on Browse page (change array index to 1-8)
												REFRESH_RATE);			//Number of milliseconds before text refreshes
#end_if

#if_defined arqDMS4
DEFINE_MODULE 'ARQ DMS UI v5_0_1' ARQ_DMS_4    (vdvDMS4,				//Virtual Keypad Device
                                                ARQ_UNITS,				//Virtual AudioReQuest Devices
                                                ARQ_SELECT_DMS,			//ARQ selection channels
												ARQ_DISCONNECT_DMS,		//ARQ deselection channel
                                                ARQ_CMDS_DMS,			//Command Channel Array
                                                ARQ_KEYBOARD_CH_DMS,	//Keyboard Channel Array
                                                ARQ_NUM_CH_DMS,			//Numbers Channel Array
                                                ARQ_FB_CH_DMS,			//Variable Text Channel Array
                                                ARQ_NUM_LINES[4], 		//Number of lines on Browse page (change array index to 1-8)
												REFRESH_RATE);			//Number of milliseconds before text refreshes
#end_if

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)
